@@ -3,10 +3,9 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 use Carp;
-use Exporter;
 use File::Find::Rule;
 use File::Temp;
 
@@ -60,7 +59,7 @@ sub read {
 sub write {
 
     my $self = shift;
-    my $p = $self->_config(@_);
+    $self->_config(@_);
 
     my $file = $self->{file};
     my $copy = $self->{copy};
@@ -124,13 +123,18 @@ sub splice {
         croak "splice() requires insert => [aref] param";
     }
 
+    if (defined $line && defined $find){
+        warn
+          "splice() can't search for both line and find. Operating on 'line'.";
+    }
+
     my @contents = $self->read($file);
 
     if (defined $line){
         splice @contents, $line, 0, @$insert;
     }
 
-    if ($find){
+    if (defined $find && ! defined $line){
         $find = qr{$find};
 
         my $i = 0;
@@ -184,7 +188,7 @@ sub dir {
         $self->write(
                     file => $file, 
                     contents => \@contents, 
-                    recsep => $recsep || $self->platform_recsep,
+                    recsep => defined $recsep ? $recsep : $self->platform_recsep,
                 );
     }
 
@@ -260,7 +264,7 @@ sub platform_recsep {
     print $wfh "abc\n";
 
     close $wfh
-      or croak "platform_recsep() can't close temp file $file write: $!";
+      or croak "platform_recsep() can't close write temp file $file: $!";
 
     my $fh = $self->_open($file);
 
@@ -310,12 +314,14 @@ sub _config {
 }
 sub _handle {
 
+    # returns a handle with platform's record separator
+
     my $self = shift;
     my $file = shift;
    
     my $fh;
 
-    if ($self->recsep($file, 'hex') ne $self->platform_recsep('hex')){ 
+    if ($self->recsep($file, 'hex') ne $self->platform_recsep('hex')){
         
         $fh = $self->_open($file);
         my $temp_wfh = $self->tempfile;
@@ -349,6 +355,8 @@ sub _handle {
 }
 sub _open {
 
+    # returns a handle opened with binmode :raw
+
     my $self = shift;
     my $file = shift;
     my $mode = shift || 'r';
